@@ -6,32 +6,13 @@ import (
 	"fmt"
 	"os"
 	"reflect"
-	"strings"
 	"testing"
 
 	"github.com/pkg/diff"
 	"github.com/pkg/diff/write"
-	"github.com/spf13/cobra"
 	yaml "gopkg.in/yaml.v3"
 )
 
-type resulter struct {
-	Error   error
-	Output  string
-	Command *cobra.Command
-}
-
-func RunCmd(c *cobra.Command, input string) resulter {
-	buf := new(bytes.Buffer)
-	c.SetOutput(buf)
-	c.SetArgs(strings.Split(input, " "))
-
-	err := c.Execute()
-	output := buf.String()
-
-	return resulter{err, output, c}
-}
-
 func ParseData(rawData string) yaml.Node {
 	var parsedData yaml.Node
 	err := yaml.Unmarshal([]byte(rawData), &parsedData)
@@ -42,17 +23,29 @@ func ParseData(rawData string) yaml.Node {
 	return parsedData
 }
 
+func printDifference(t *testing.T, expectedValue interface{}, actualValue interface{}) {
+	opts := []write.Option{write.TerminalColor()}
+	var differenceBuffer bytes.Buffer
+	expectedString := fmt.Sprintf("%v", expectedValue)
+	actualString := fmt.Sprintf("%v", actualValue)
+	if err := diff.Text("expected", "actual", expectedString, actualString, bufio.NewWriter(&differenceBuffer), opts...); err != nil {
+		t.Error(err)
+	} else {
+		t.Error(differenceBuffer.String())
+	}
+}
+
 func AssertResult(t *testing.T, expectedValue interface{}, actualValue interface{}) {
 	t.Helper()
 	if expectedValue != actualValue {
-		t.Error("Expected <", expectedValue, "> but got <", actualValue, ">", fmt.Sprintf("%T", actualValue))
+		printDifference(t, expectedValue, actualValue)
 	}
 }
 
 func AssertResultComplex(t *testing.T, expectedValue interface{}, actualValue interface{}) {
 	t.Helper()
 	if !reflect.DeepEqual(expectedValue, actualValue) {
-		t.Error("\nExpected <", expectedValue, ">\nbut got  <", actualValue, ">", fmt.Sprintf("%T", actualValue))
+		printDifference(t, expectedValue, actualValue)
 	}
 }
 
@@ -60,7 +53,7 @@ func AssertResultComplexWithContext(t *testing.T, expectedValue interface{}, act
 	t.Helper()
 	if !reflect.DeepEqual(expectedValue, actualValue) {
 		t.Error(context)
-		t.Error("\nExpected <", expectedValue, ">\nbut got  <", actualValue, ">", fmt.Sprintf("%T", actualValue))
+		printDifference(t, expectedValue, actualValue)
 	}
 }
 
